# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class GuestPortalUserDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'portal_id': 'str',
        'name': 'str',
        'username': 'str',
        'email_address': 'str',
        'inbox_id': 'str',
        'login_url': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'portal_id': 'portalId',
        'name': 'name',
        'username': 'username',
        'email_address': 'emailAddress',
        'inbox_id': 'inboxId',
        'login_url': 'loginUrl',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, user_id=None, portal_id=None, name=None, username=None, email_address=None, inbox_id=None, login_url=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """GuestPortalUserDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._portal_id = None
        self._name = None
        self._username = None
        self._email_address = None
        self._inbox_id = None
        self._login_url = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.portal_id = portal_id
        if name is not None:
            self.name = name
        self.username = username
        if email_address is not None:
            self.email_address = email_address
        if inbox_id is not None:
            self.inbox_id = inbox_id
        self.login_url = login_url
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this GuestPortalUserDto.  # noqa: E501


        :return: The id of this GuestPortalUserDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this GuestPortalUserDto.


        :param id: The id of this GuestPortalUserDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this GuestPortalUserDto.  # noqa: E501


        :return: The user_id of this GuestPortalUserDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this GuestPortalUserDto.


        :param user_id: The user_id of this GuestPortalUserDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def portal_id(self):
        """Gets the portal_id of this GuestPortalUserDto.  # noqa: E501


        :return: The portal_id of this GuestPortalUserDto.  # noqa: E501
        :rtype: str
        """
        return self._portal_id

    @portal_id.setter
    def portal_id(self, portal_id):
        """Sets the portal_id of this GuestPortalUserDto.


        :param portal_id: The portal_id of this GuestPortalUserDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and portal_id is None:  # noqa: E501
            raise ValueError("Invalid value for `portal_id`, must not be `None`")  # noqa: E501

        self._portal_id = portal_id

    @property
    def name(self):
        """Gets the name of this GuestPortalUserDto.  # noqa: E501


        :return: The name of this GuestPortalUserDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GuestPortalUserDto.


        :param name: The name of this GuestPortalUserDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def username(self):
        """Gets the username of this GuestPortalUserDto.  # noqa: E501


        :return: The username of this GuestPortalUserDto.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this GuestPortalUserDto.


        :param username: The username of this GuestPortalUserDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and username is None:  # noqa: E501
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501

        self._username = username

    @property
    def email_address(self):
        """Gets the email_address of this GuestPortalUserDto.  # noqa: E501


        :return: The email_address of this GuestPortalUserDto.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this GuestPortalUserDto.


        :param email_address: The email_address of this GuestPortalUserDto.  # noqa: E501
        :type: str
        """

        self._email_address = email_address

    @property
    def inbox_id(self):
        """Gets the inbox_id of this GuestPortalUserDto.  # noqa: E501


        :return: The inbox_id of this GuestPortalUserDto.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this GuestPortalUserDto.


        :param inbox_id: The inbox_id of this GuestPortalUserDto.  # noqa: E501
        :type: str
        """

        self._inbox_id = inbox_id

    @property
    def login_url(self):
        """Gets the login_url of this GuestPortalUserDto.  # noqa: E501


        :return: The login_url of this GuestPortalUserDto.  # noqa: E501
        :rtype: str
        """
        return self._login_url

    @login_url.setter
    def login_url(self, login_url):
        """Sets the login_url of this GuestPortalUserDto.


        :param login_url: The login_url of this GuestPortalUserDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and login_url is None:  # noqa: E501
            raise ValueError("Invalid value for `login_url`, must not be `None`")  # noqa: E501

        self._login_url = login_url

    @property
    def created_at(self):
        """Gets the created_at of this GuestPortalUserDto.  # noqa: E501


        :return: The created_at of this GuestPortalUserDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this GuestPortalUserDto.


        :param created_at: The created_at of this GuestPortalUserDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this GuestPortalUserDto.  # noqa: E501


        :return: The updated_at of this GuestPortalUserDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this GuestPortalUserDto.


        :param updated_at: The updated_at of this GuestPortalUserDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GuestPortalUserDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GuestPortalUserDto):
            return True

        return self.to_dict() != other.to_dict()
