# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mailslurp_client
from mailslurp_client.models.page_ai_transform_projection import PageAITransformProjection  # noqa: E501
from mailslurp_client.rest import ApiException

class TestPageAITransformProjection(unittest.TestCase):
    """PageAITransformProjection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PageAITransformProjection
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mailslurp_client.models.page_ai_transform_projection.PageAITransformProjection()  # noqa: E501
        if include_optional :
            return PageAITransformProjection(
                content = [
                    mailslurp_client.models.ai_transform_projection.AITransformProjection(
                        conditions = [
                            '0'
                            ], 
                        instructions = [
                            '0'
                            ], 
                        output_schema = mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                            any_of = [
                                mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                                    default = mailslurp_client.models.meta_data.metaData(), 
                                    description = '0', 
                                    enum = [
                                        '0'
                                        ], 
                                    example = mailslurp_client.models.meta_data.metaData(), 
                                    format = '0', 
                                    items = mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                                        default = mailslurp_client.models.meta_data.metaData(), 
                                        description = '0', 
                                        example = mailslurp_client.models.meta_data.metaData(), 
                                        format = '0', 
                                        max_items = 0, 
                                        min_items = 0, 
                                        max_length = 0, 
                                        min_length = 0, 
                                        pattern = '0', 
                                        properties = {
                                            'key' : mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                                                default = mailslurp_client.models.meta_data.metaData(), 
                                                description = '0', 
                                                example = mailslurp_client.models.meta_data.metaData(), 
                                                format = '0', 
                                                max_items = 0, 
                                                min_items = 0, 
                                                max_length = 0, 
                                                min_length = 0, 
                                                pattern = '0', 
                                                property_ordering = [
                                                    '0'
                                                    ], 
                                                required = [
                                                    '0'
                                                    ], 
                                                max_properties = 0, 
                                                min_properties = 0, 
                                                maximum = 1.337, 
                                                minimum = 1.337, 
                                                nullable = True, 
                                                title = '0', 
                                                type = 'string', )
                                            }, 
                                        property_ordering = [
                                            '0'
                                            ], 
                                        required = [
                                            '0'
                                            ], 
                                        max_properties = 0, 
                                        min_properties = 0, 
                                        maximum = 1.337, 
                                        minimum = 1.337, 
                                        nullable = True, 
                                        title = '0', 
                                        type = 'string', ), 
                                    max_items = 0, 
                                    min_items = 0, 
                                    max_length = 0, 
                                    min_length = 0, 
                                    pattern = '0', 
                                    properties = {
                                        'key' : mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                                            default = mailslurp_client.models.meta_data.metaData(), 
                                            description = '0', 
                                            example = mailslurp_client.models.meta_data.metaData(), 
                                            format = '0', 
                                            max_items = 0, 
                                            min_items = 0, 
                                            max_length = 0, 
                                            min_length = 0, 
                                            pattern = '0', 
                                            max_properties = 0, 
                                            min_properties = 0, 
                                            maximum = 1.337, 
                                            minimum = 1.337, 
                                            nullable = True, 
                                            title = '0', 
                                            type = 'string', )
                                        }, 
                                    property_ordering = [
                                        '0'
                                        ], 
                                    required = [
                                        '0'
                                        ], 
                                    max_properties = 0, 
                                    min_properties = 0, 
                                    maximum = 1.337, 
                                    minimum = 1.337, 
                                    nullable = True, 
                                    title = '0', 
                                    type = 'string', )
                                ], 
                            default = mailslurp_client.models.meta_data.metaData(), 
                            description = '0', 
                            enum = [
                                '0'
                                ], 
                            example = mailslurp_client.models.meta_data.metaData(), 
                            format = '0', 
                            items = mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                                default = mailslurp_client.models.meta_data.metaData(), 
                                description = '0', 
                                example = mailslurp_client.models.meta_data.metaData(), 
                                format = '0', 
                                max_items = 0, 
                                min_items = 0, 
                                max_length = 0, 
                                min_length = 0, 
                                pattern = '0', 
                                max_properties = 0, 
                                min_properties = 0, 
                                maximum = 1.337, 
                                minimum = 1.337, 
                                nullable = True, 
                                title = '0', 
                                type = 'string', ), 
                            max_items = 0, 
                            min_items = 0, 
                            max_length = 0, 
                            min_length = 0, 
                            pattern = '0', 
                            properties = {
                                'key' : mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                                    default = mailslurp_client.models.meta_data.metaData(), 
                                    description = '0', 
                                    example = mailslurp_client.models.meta_data.metaData(), 
                                    format = '0', 
                                    max_items = 0, 
                                    min_items = 0, 
                                    max_length = 0, 
                                    min_length = 0, 
                                    pattern = '0', 
                                    max_properties = 0, 
                                    min_properties = 0, 
                                    maximum = 1.337, 
                                    minimum = 1.337, 
                                    nullable = True, 
                                    title = '0', 
                                    type = 'string', )
                                }, 
                            property_ordering = [
                                '0'
                                ], 
                            required = [
                                '0'
                                ], 
                            max_properties = 0, 
                            min_properties = 0, 
                            maximum = 1.337, 
                            minimum = 1.337, 
                            nullable = True, 
                            title = '0', 
                            type = 'string', ), 
                        name = '0', 
                        id = '0', )
                    ], 
                pageable = mailslurp_client.models.pageable_object.PageableObject(
                    page_size = 56, 
                    paged = True, 
                    page_number = 56, 
                    unpaged = True, 
                    offset = 56, 
                    sort = mailslurp_client.models.sort_object.SortObject(
                        sorted = True, 
                        unsorted = True, 
                        empty = True, ), ), 
                total_elements = 56, 
                total_pages = 56, 
                last = True, 
                number_of_elements = 56, 
                first = True, 
                size = 56, 
                number = 56, 
                sort = mailslurp_client.models.sort_object.SortObject(
                    sorted = True, 
                    unsorted = True, 
                    empty = True, ), 
                empty = True
            )
        else :
            return PageAITransformProjection(
                total_elements = 56,
                total_pages = 56,
        )

    def testPageAITransformProjection(self):
        """Test PageAITransformProjection"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
